import 'package:flutter/material.dart';
import 'package:flutter_calendar_carousel/classes/event.dart';
import 'package:flutter_calendar_carousel/flutter_calendar_carousel.dart';
import 'package:intl/intl.dart';

class UplanitCalendarView extends StatefulWidget {
  final Color primaryColor;
  final Function markedAvailableCallback;
  final Function(DateTime date, List<Event> events) onDateSelected;
  const UplanitCalendarView({
    Key key,
    this.primaryColor,
    this.markedAvailableCallback,
    this.onDateSelected,
  }) : super(key: key);

  @override
  _UplanitCalendarViewState createState() => _UplanitCalendarViewState();
}

class _UplanitCalendarViewState extends State<UplanitCalendarView> {
  DateTime _currentDate = DateTime.now();

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.all(16),
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          InkWell(
            onTap: widget.markedAvailableCallback,
            child: Container(
              padding: const EdgeInsets.all(10),
              decoration: BoxDecoration(
                color: Color(0xFFF5F5F5),
                borderRadius: BorderRadius.circular(2),
              ),
              child: Text(
                'Mark ${DateFormat('MMMM').format(_currentDate)} as available',
              ),
            ),
          ),
          CalendarCarousel(
            onCalendarChanged: (DateTime date) {
              this.setState(() {
                _currentDate = date;
              });
            },
            onDayPressed: (DateTime date, List<Event> events) {
              this.setState(() {
                _currentDate = date;
                widget.onDateSelected(date, events);
              });
            },
            weekendTextStyle: TextStyle(
              color: Colors.black,
            ),

            showWeekDays: true,
            headerTextStyle: TextStyle(
              color: Colors.black,
              fontSize: 22,
              fontWeight: FontWeight.w500,
            ),
            leftButtonIcon: Icon(
              Icons.arrow_back_ios,
              size: 30,
            ),
            rightButtonIcon: Icon(
              Icons.arrow_forward_ios,
              size: 30,
            ),
            headerTitleTouchable: true,
            weekdayTextStyle: TextStyle(
              color: Colors.black,
              fontSize: 12,
            ),
            selectedDayButtonColor: Colors.transparent,
            selectedDayBorderColor: Colors.transparent,
            todayButtonColor: Colors.transparent,
            todayBorderColor: Colors.transparent,

            /// for pass null when you do not want to render weekDays
            //  headerText: Container(
            //    child: Text('Custom Header'),
            //  ),
            customDayBuilder: (
              /// you can provide your own build function to make custom day containers
              bool isSelectable,
              int index,
              bool isSelectedDay,
              bool isToday,
              bool isPrevMonthDay,
              TextStyle textStyle,
              bool isNextMonthDay,
              bool isThisMonthDay,
              DateTime day,
            ) {
              // print('isSelectable: $isSelectable');
              // print('index: $index');
              // print('isSelectedDay: $isSelectedDay');
              // print('isToday: $isToday');
              // print('isPrevMonthDay: $isPrevMonthDay');
              // print('textStyle: $textStyle');
              // print('isNextMonthDay: $isNextMonthDay');
              // print('isThisMonthDay: $isThisMonthDay');
              // print('datetime: $day');

              /// If you return null, [CalendarCarousel] will build container for current [day] with default function.
              /// This way you can build custom containers for specific days only, leaving rest as default.
              if (isToday) {
                return Container(
                  decoration: BoxDecoration(
                    color: widget.primaryColor,
                    shape: BoxShape.circle,
                  ),
                  child: Center(
                    child: Text(
                      '${day.day}',
                      style: TextStyle(
                        color: Colors.white,
                        fontSize: 18,
                      ),
                    ),
                  ),
                );
              }
              if (isSelectedDay) {
                return Container(
                  decoration: BoxDecoration(
                    border: Border.all(
                      width: 2,
                      color: widget.primaryColor,
                    ),
                    shape: BoxShape.circle,
                  ),
                  child: Center(
                    child: Text(
                      '${day.day}',
                      style: TextStyle(
                        color: Colors.black,
                        fontSize: 16,
                        fontWeight: FontWeight.w400,
                      ),
                    ),
                  ),
                );
              } else {
                return null;
              }
            },
            weekFormat: false,
            // markedDatesMap: _markedDateMap,
            height: 360.0,
            selectedDateTime: _currentDate,
            daysHaveCircularBorder: false,
            daysTextStyle: TextStyle(
              fontSize: 16,
              color: Colors.black,
            ),
            markedDateShowIcon: true,
            showIconBehindDayText: true,
            markedDateIconBorderColor: Colors.black,

            /// null for not rendering any border, true for circular border, false for rectangular border
          ),
        ],
      ),
    );
  }
}
